@@ -119,13 +119,6 @@ Builtin constant %s resolved""" % self.builtin_name
         # TODO: Why yes, some may be, could be told here.
         return None
 
-    def mayProvideReference(self):
-        # Dedicated code returns which returns from builtin module dictionary,
-        # but isn't available for Python3 yet.
-
-        return python_version >= 300
-
-
 
 class ExpressionBuiltinOriginalRef(ExpressionBuiltinRef):
     kind = "EXPRESSION_BUILTIN_ORIGINAL_REF"
@@ -158,12 +151,6 @@ class ExpressionBuiltinAnonymousRef(ExpressionBuiltinRefBase):
         # Virtual method, pylint: disable=R0201
         return True
 
-    def mayProvideReference(self):
-        # No reference provided from this, there are just a global identifiers,
-        # or accesses to them.
-
-        return False
-
     def getCompileTimeConstant(self):
         return builtin_anon_names[ self.builtin_name ]
 
@@ -198,11 +185,6 @@ class ExpressionBuiltinExceptionRef(ExpressionBuiltinRefBase):
     def mayRaiseException(self, exception_type):
         return False
 
-    def mayProvideReference(self):
-        # No reference provided from this, it's just a global identifier.
-
-        return False
-
     def getCompileTimeConstant(self):
         return builtin_exception_values[ self.builtin_name ]
 
